@@ -7,12 +7,12 @@ use warnings;
 
 package POSIX::1003::Module;
 use vars '$VERSION';
-$VERSION = '0.94_3';
+$VERSION = '0.94_4';
 
 
 # The VERSION of the distribution is sourced from this file, because
 # this module also loads the XS extension.
-our $VERSION = '0.94_3';
+our $VERSION = '0.94_4';
 use Carp 'croak';
 
 { use XSLoader;
@@ -26,7 +26,9 @@ BEGIN { $in_constant_table = qr/
    ^_CS_    # confstr
  | ^DN_     # fcntl
  | ^E(?!CHONL|XIT_) # errno   ECHONL in Termios, EXIT_ in Proc
+ | ^FCNTL   # fcntl
  | ^F_      # fcntl
+ | ^FD_     # fcntl
  | ^GET_    # rlimit
  | ^O_      # fdio
  | ^_PC_    # pathconf
@@ -143,7 +145,7 @@ sub exampleValue($)
 
 package POSIX::1003::ReadOnlyTable;
 use vars '$VERSION';
-$VERSION = '0.94_3';
+$VERSION = '0.94_4';
 
 sub TIEHASH($) { bless $_[1], $_[0] }
 sub FETCH($)   { $_[0]->{$_[1]} }
